==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-commons/nifi-site-to-site-client/src/main/java/org/apache/nifi/remote/cluster/NodeInformationAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.remote.cluster;

import javax.xml.bind.annotation.adapters.XmlAdapter;

public class NodeInformationAdapter extends XmlAdapter<AdaptedNodeInformation, NodeInformation> {

    @Override
    public NodeInformation unmarshal(final AdaptedNodeInformation adapted) throws Exception {
        return new NodeInformation(adapted.getHostname(), adapted.getSiteToSitePort(), adapted.getSiteToSiteHttpApiPort(),
                adapted.getApiPort(), adapted.isSiteToSiteSecure(), adapted.getTotalFlowFiles());
    }

    @Override
    public AdaptedNodeInformation marshal(final NodeInformation nodeInformation) throws Exception {
        final AdaptedNodeInformation adapted = new AdaptedNodeInformation();
        adapted.setHostname(nodeInformation.getSiteToSiteHostname());
        adapted.setSiteToSitePort(nodeInformation.getSiteToSitePort());
        adapted.setSiteToSiteHttpApiPort(nodeInformation.getSiteToSiteHttpApiPort());
        adapted.setApiPort(nodeInformation.getAPIPort());
        adapted.setSiteToSiteSecure(nodeInformation.isSiteToSiteSecure());
        adapted.setTotalFlowFiles(nodeInformation.getTotalFlowFiles());
        return adapted;
    }

}

==> nifi-2.6.0-source-release.zip: nifi-2.6.0/nifi-commons/nifi-site-to-site-client/src/main/java/org/apache/nifi/remote/cluster/NodeInformationAdapter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.remote.cluster;

import jakarta.xml.bind.annotation.adapters.XmlAdapter;

public class NodeInformationAdapter extends XmlAdapter<AdaptedNodeInformation, NodeInformation> {

    @Override
    public NodeInformation unmarshal(final AdaptedNodeInformation adapted) throws Exception {
        return new NodeInformation(adapted.getHostname(), adapted.getSiteToSitePort(), adapted.getSiteToSiteHttpApiPort(),
                adapted.getApiPort(), adapted.isSiteToSiteSecure(), adapted.getTotalFlowFiles());
    }

    @Override
    public AdaptedNodeInformation marshal(final NodeInformation nodeInformation) throws Exception {
        final AdaptedNodeInformation adapted = new AdaptedNodeInformation();
        adapted.setHostname(nodeInformation.getSiteToSiteHostname());
        adapted.setSiteToSitePort(nodeInformation.getSiteToSitePort());
        adapted.setSiteToSiteHttpApiPort(nodeInformation.getSiteToSiteHttpApiPort());
        adapted.setApiPort(nodeInformation.getAPIPort());
        adapted.setSiteToSiteSecure(nodeInformation.isSiteToSiteSecure());
        adapted.setTotalFlowFiles(nodeInformation.getTotalFlowFiles());
        return adapted;
    }

}
